/*
 * TI Booting and Flashing Utilities
 *
 * Provides device differentiation for the project files. This file MUST be
 * modified to match the device specifics.
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef _DEVICE_H_
#define _DEVICE_H_

#include "tistdtypes.h"

// Prevent C++ name mangling
#ifdef __cplusplus
extern far "c" {
#endif

/***********************************************************
* Global Macro Declarations                                *
***********************************************************/

#define DEVICE_ARM_UBL_LOAD_ADDR		(0x80000BEC)

/******************************************************
* Global Typedef declarations                         *
******************************************************/

// System Control Module register structure
typedef struct _DEVICE_SYS_MODULE_REGS_
{
  VUint32 REVID;              //0x00
  VUint8  RSVD0[4];			  //0x04
  VUint32 DIEIDR[4];          //0x08
  VUint8  RSVD1[8];           //0x14
  VUint32 BOOTCFG;            //0x20
  VUint8  RSVD2[20];          //0x24
  VUint32 KICKR[2];           //0x38
  VUint32 HOSTCFG[2];         //0x40
  VUint8  RSVD3[152];         //0x48
  VUint32 IRAWSTRAT;          //0xE0
  VUint32 IENSTAT;            //0xE4
  VUint32 IENSET;             //0xE8
  VUint32 IENCLR;             //0xEC
  VUint32 EOI;                //0xF0
  VUint32 FLTADDRR;           //0xF4  
  VUint32 FLTSTAT;            //0xF8
  VUint8  RSVD4[20];          //0xFC
  VUint32 MSTPRI[3];          //0x110
  VUint8  RSVD5[4];           //0x11C
  VUint32 PINMUX[20];         //0x120
  VUint32 SUSPSRC;            //0x170
  VUint32 CHIPSIG;            //0x174
  VUint32 CHIPSIG_CLR;        //0x178
  VUint32 CFGCHIP[5];         //0x17C
}
DEVICE_SysModuleRegs;

#define SYSTEM ((DEVICE_SysModuleRegs*) 0x01C14000)

#define SYS_BASE            (0x01C14000)


// PLL Register structure - See sprufb3.pdf, Chapter 6 for more details.
typedef struct _DEVICE_PLL_REGS_
{
  VUint32 PID;
  VUint8 RSVD0[224];
  VUint32 RSTYPE;
  VUint8 RSVD1[24];  
  VUint32 PLLCTL;
  VUint8 RSVD2[12];  
  VUint32 PLLM;
  VUint8 RSVD3[4];
  VUint32 PLLDIV1;
  VUint32 PLLDIV2;
  VUint32 PLLDIV3;  
  VUint8 RSVD4[4]; 
  VUint32 POSTDIV;
  VUint32 BPDIV;
  VUint8 RSVD5[8];  
  VUint32 PLLCMD;
  VUint32 PLLSTAT;
  VUint32 ALNCTL;
  VUint32 DCHANGE;
  VUint32 CKEN;
  VUint32 CKSTAT;
  VUint32 SYSTAT;
  VUint8 RSVD6[12];
  VUint32 PLLDIV4;
  VUint32 PLLDIV5;
  VUint32 PLLDIV6;
  VUint32 PLLDIV7;
}
DEVICE_PLLRegs;

#define PLL ((DEVICE_PLLRegs*) 0x01c11000)

#define DEVICE_PLLCTL_PLLEN_MASK    (0x00000001)
#define DEVICE_PLLCTL_PLLPWRDN_MASK (0x00000002)
#define DEVICE_PLLCTL_PLLRST_MASK   (0x00000008)
#define DEVICE_PLLCTL_PLLDIS_MASK   (0x00000010)
#define DEVICE_PLLCTL_PLLENSRC_MASK (0x00000020)
#define DEVICE_PLLCTL_CLKMODE_MASK  (0x00000100)

#define DEVICE_PLLCMD_GOSET_MASK    (0x00000001)
#define DEVICE_PLLSTAT_GOSTAT_MASK  (0x00000001)
#define DEVICE_PLLDIV_EN_MASK       (0x00008000)

#define DEVICE_PLL0_MULTIPLIER		(24u)

#define DEVICE_OSC_FREQ         	(24000000u)

// Power/Sleep Ctrl Register structure - See sprufb3.pdf, Chapter 7
typedef struct _DEVICE_PSC_REGS_
{
  VUint32 PID;        // 0x000
  VUint8 RSVD0[16];   // 0x004
  VUint8 RSVD1[4];    // 0x014
  VUint32 INTEVAL;    // 0x018
  VUint8 RSVD2[36];   // 0x01C
  VUint32 MERRPR0;    // 0x040
  VUint32 MERRPR1;    // 0x044
  VUint8 RSVD3[8];    // 0x048
  VUint32 MERRCR0;    // 0x050
  VUint32 MERRCR1;    // 0x054
  VUint8 RSVD4[8];    // 0x058
  VUint32 PERRPR;     // 0x060
  VUint8 RSVD5[4];    // 0x064
  VUint32 PERRCR;     // 0x068
  VUint8 RSVD6[4];    // 0x06C
  VUint32 EPCPR;      // 0x070
  VUint8 RSVD7[4];    // 0x074
  VUint32 EPCCR;      // 0x078
  VUint8 RSVD8[144];  // 0x07C
  VUint8 RSVD9[20];   // 0x10C
  VUint32 PTCMD;      // 0x120
  VUint8 RSVD10[4];   // 0x124
  VUint32 PTSTAT;     // 0x128
  VUint8 RSVD11[212]; // 0x12C
  VUint32 PDSTAT0;    // 0x200
  VUint32 PDSTAT1;    // 0x204
  VUint8 RSVD12[248]; // 0x208
  VUint32 PDCTL0;     // 0x300
  VUint32 PDCTL1;     // 0x304
  VUint8 RSVD13[536]; // 0x308
  VUint32 MCKOUT0;    // 0x520
  VUint32 MCKOUT1;    // 0x524
  VUint8 RSVD14[728]; // 0x528
  VUint32 MDSTAT[41]; // 0x800
  VUint8 RSVD15[348]; // 0x8A4
  VUint32 MDCTL[41];  // 0xA00
}
DEVICE_PSCRegs;

#define PSC0 ((DEVICE_PSCRegs*) 0x01C10000)
#define PSC1 ((DEVICE_PSCRegs*) 0x01E27000)

// PSC constants
#define LPSC_TPCC0			(0)
#define LPSC_TPTC0			(1)
#define LPSC_TPTC1			(2)
#define LPSC_EMIF25			(3)
#define LPSC_SPI0			(4)
#define LPSC_MMCSD0			(5)
#define LPSC_AINTC			(6)
#define LPSC_ARM_RAM		(7)
#define LPSC_SEC_KEYMGR		(8)
#define LPSC_UART0			(9)
#define LPSC_SCR0SS			(10)
#define LPSC_SCR1SS			(11)
#define LPSC_SCR2SS			(12)
#define LPSC_DMAX			(13)
#define LPSC_ARM			(14)
#define LPSC_DSP			(15)

#define EMURSTIE_MASK       (0x00000200)

#define PD0                 (0)

#define PSC_ENABLE          (0x3)
#define PSC_DISABLE         (0x2)
#define PSC_SYNCRESET       (0x1)
#define PSC_SWRSTDISABLE    (0x0)
#define PSC_ENABLE_LRESET   (0x103)

typedef struct  {
    VUint32 CONTROL;
    VUint32 STATUS;
    VUint32 WAKEUP;
    VUint32 CYCLECNT;
    VUint32 STALLCNT;
    VUint8 RSVD0[12];
    VUint32 CONTABBLKIDX0;
    VUint32 CONTABBLKIDX1;
    VUint32 CONTABPROPTR0;
    VUint32 CONTABPROPTR1;
    VUint8 RSVD1[976];
    VUint32 INTGPR0;
    VUint32 INTGPR1;
    VUint32 INTGPR2;
    VUint32 INTGPR3;
    VUint32 INTGPR4;
    VUint32 INTGPR5;
    VUint32 INTGPR6;
    VUint32 INTGPR7;
    VUint32 INTGPR8;
    VUint32 INTGPR9;
    VUint32 INTGPR10;
    VUint32 INTGPR11;
    VUint32 INTGPR12;
    VUint32 INTGPR13;
    VUint32 INTGPR14;
    VUint32 INTGPR15;
    VUint32 INTGPR16;
    VUint32 INTGPR17;
    VUint32 INTGPR18;
    VUint32 INTGPR19;
    VUint32 INTGPR20;
    VUint32 INTGPR21;
    VUint32 INTGPR22;
    VUint32 INTGPR23;
    VUint32 INTGPR24;
    VUint32 INTGPR25;
    VUint32 INTGPR26;
    VUint32 INTGPR27;
    VUint32 INTGPR28;
    VUint32 INTGPR29;
    VUint32 INTGPR30;
    VUint32 INTGPR31;
    VUint32 INTCTER0;
    VUint32 INTCTER1;
    VUint32 INTCTER2;
    VUint32 INTCTER3;
    VUint32 INTCTER4;
    VUint32 INTCTER5;
    VUint32 INTCTER6;
    VUint32 INTCTER7;
    VUint32 INTCTER8;
    VUint32 INTCTER9;
    VUint32 INTCTER10;
    VUint32 INTCTER11;
    VUint32 INTCTER12;
    VUint32 INTCTER13;
    VUint32 INTCTER14;
    VUint32 INTCTER15;
    VUint32 INTCTER16;
    VUint32 INTCTER17;
    VUint32 INTCTER18;
    VUint32 INTCTER19;
    VUint32 INTCTER20;
    VUint32 INTCTER21;
    VUint32 INTCTER22;
    VUint32 INTCTER23;
    VUint32 INTCTER24;
    VUint32 INTCTER25;
    VUint32 INTCTER26;
    VUint32 INTCTER27;
    VUint32 INTCTER28;
    VUint32 INTCTER29;
    VUint32 INTCTER30;
    VUint32 INTCTER31;
} DEVICE_DmaxpdspRegs;

typedef volatile DEVICE_DmaxpdspRegs        *DEVICE_DmaxpdspRegsOvly;

#define DMAXPDSP0              				((DEVICE_DmaxpdspRegsOvly) 0x01C37000u)
#define DMAXPDSP0_IRAM_BASEADDR             (0x01C38000u)

#define DMAXPDSP_CONTROL_RESETVAL (0x00000000u)


/***********************************************************
* Global Function Declarations                             *
***********************************************************/

// Execute LPSC state transition
void    DEVICE_LPSCTransition(Uint8 pscnum, Uint8 module, Uint8 domain, Uint8 state);

void DEVICE_enable_ARM();

/***********************************************************
* End file                                                 *
***********************************************************/

#ifdef __cplusplus
}
#endif

#endif // End _DEVICE_H_

/* --------------------------------------------------------------------------
    HISTORY
       v1.00  -  DJA  -  07-Nov-2007
         Initial Release
 ----------------------------------------------------------------------------- */
